<?php

namespace Drupal\migrate_conditions\Plugin\migrate\process;

use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;
use Drupal\migrate_conditions\Plugin\ProcessPluginWithConditionBase;

/**
 * Get configured properties based on result of a condition.
 *
 * Available configuration keys:
 * - condition: The condition plugin to evaluate on each element.
 *   Can be either:
 *   - The id of the condition. This is possible if the condition does not
 *     require any configuration, such as the 'empty' condition.
 *   - An array with a 'plugin' key that is the id of the condition.
 *     Any additional properties will be used as configuration when
 *     creating an instance of the condition.
 * - do_get: (optional) property to get and return if condition is met. If not
 *   set, the source will be used.
 * - else_get: (optional) property to get and return if condition is not met. If
 *   not set, NULL will be returned.
 *
 * Examples:
 *
 * If animal_family is 'bird', get feather_color. Otherwise, get
 * fur_color.
 *
 * @code
 * process:
 *   animal_color:
 *     plugin: if_condition
 *     source: animal_family
 *     condition:
 *       plugin: equals
 *       value: bird
 *     do_get: feather_color
 *     else_get: fur_color
 * @endcode
 *
 * The if_condition process plugin can work like the default_value
 * process plugin but with a source value as the default. For example,
 * use field_backup if field_i_want_to_use is empty.
 *
 * @code
 * process:
 *   destination_value:
 *     plugin: if_condition
 *     source: field_i_want_to_use
 *     condition:
 *       plugin: empty
 *       negate: true
 *     else_get: field_backup
 * @endcode
 *
 * or equivalently:
 *
 * @code
 * process:
 *   destination_value:
 *     plugin: if_condition
 *     source: field_i_want_to_use
 *     condition: empty
 *     do_get: field_backup
 *     else_get: field_i_want_to_use
 * @endcode
 *
 * @MigrateProcessPlugin(
 *   id = "if_condition",
 *   handle_multiples = TRUE
 * )
 */
class IfCondition extends ProcessPluginWithConditionBase {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
    if ($this->condition->evaluate($value, $row)) {
      if (isset($this->configuration['do_get'])) {
        return $row->get($this->configuration['do_get']);
      }
      else {
        return $value;
      }
    }
    else {
      if (isset($this->configuration['else_get'])) {
        return $row->get($this->configuration['else_get']);
      }
      else {
        return NULL;
      }
    }
  }

}
